@@ -58,7 +58,7 @@ positional and keysword arguments.
 Any underlying PyQt5 instance can be accessed directly using property ```qt```.
 
 >>> widget.qt.setWindowTitle("Spam!")
->>> widget.qt.customContextMenuRequested.conenct(lambda pos: None)
+>>> widget.qt.customContextMenuRequested.connect(lambda pos: None)
 
 """
 
@@ -76,6 +76,7 @@ from .layout import *
 from .list import *
 from .mainwindow import *
 from .menu import *
+from .menubar import *
 from .messagebox import *
 from .number import *
 from .object import *
@@ -90,8 +91,9 @@ from .tabs import *
 from .text import *
 from .textarea import *
 from .timer import *
+from .toolbar import *
 from .tree import *
 from .widget import *
 from .worker import *
 
-__version__ = '1.4.1'
+__version__ = '1.6.0'
