@@ -1,12 +1,12 @@
-from .qt import QtWidgets
-from .qt import bind
+from .qutie import QtWidgets
 
 from .widget import BaseWidget
 
 __all__ = ['Frame']
 
-@bind(QtWidgets.QFrame)
 class Frame(BaseWidget):
 
+    QtClass = QtWidgets.QFrame
+
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
